@@ -113,7 +113,7 @@ class CmeClient(AbstractClient):
 
 
     def CreateProject(self, request):
-        """创建云剪的编辑项目，支持创建视频剪辑、直播剪辑及导播台项目。
+        """创建云剪的编辑项目，支持创建视频剪辑、直播剪辑、导播台项目以及视频拆条项目。
 
         :param request: Request instance for CreateProject.
         :type request: :class:`tencentcloud.cme.v20191029.models.CreateProjectRequest`
@@ -452,6 +452,36 @@ class CmeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribePlatforms(self, request):
+        """<li>支持获取所创建的所有平台列表信息；</li>
+        <li>支持获取指定的平台列表信息。</li>
+
+
+        :param request: Request instance for DescribePlatforms.
+        :type request: :class:`tencentcloud.cme.v20191029.models.DescribePlatformsRequest`
+        :rtype: :class:`tencentcloud.cme.v20191029.models.DescribePlatformsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribePlatforms", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribePlatformsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeProjects(self, request):
         """支持根据多种条件过滤出项目列表。
 
@@ -678,6 +708,34 @@ class CmeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ExportVideoByVideoSegmentationData(self, request):
+        """使用视频智能拆条数据导出视频，将指定的视频拆条片段导出为一个视频。
+
+        :param request: Request instance for ExportVideoByVideoSegmentationData.
+        :type request: :class:`tencentcloud.cme.v20191029.models.ExportVideoByVideoSegmentationDataRequest`
+        :rtype: :class:`tencentcloud.cme.v20191029.models.ExportVideoByVideoSegmentationDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ExportVideoByVideoSegmentationData", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ExportVideoByVideoSegmentationDataResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ExportVideoEditProject(self, request):
         """导出视频编辑项目，支持指定输出的模板。
 
@@ -734,6 +792,34 @@ class CmeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def GenerateVideoSegmentationSchemeByAi(self, request):
+        """发起视频智能拆条任务，支持智能生成和平精英集锦、王者荣耀集锦、足球集锦、篮球集锦 、人物集锦、新闻拆条等任务。
+
+        :param request: Request instance for GenerateVideoSegmentationSchemeByAi.
+        :type request: :class:`tencentcloud.cme.v20191029.models.GenerateVideoSegmentationSchemeByAiRequest`
+        :rtype: :class:`tencentcloud.cme.v20191029.models.GenerateVideoSegmentationSchemeByAiResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("GenerateVideoSegmentationSchemeByAi", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.GenerateVideoSegmentationSchemeByAiResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def GrantResourceAuthorization(self, request):
         """资源所属实体对目标实体授予目标资源的相应权限。
 
